Changes
~~~~~~~

.. Future (?)
.. ----------
.. - ...

2.0.2
-----

- Fix ``mock`` import for v15

2.0.1
-----

- Fix support for Odoo 15.0


2.0.0
-----

- Move to OCA
- Re-license to LGPL


1.1.0
-----

- Refactoring (misc imp/fix)


1.0.0
-----

- Initial release
